/* ========================================
 *
 * Copyright YOUR COMPANY, THE YEAR
 * All Rights Reserved
 * UNPUBLISHED, LICENSED SOFTWARE.
 *
 * CONFIDENTIAL AND PROPRIETARY INFORMATION
 * WHICH IS THE PROPERTY OF your company.
 *
 * ========================================
*/
#include <device.h>
#include <stdio.h>
#include <string.h>

#define forever 1	// I like that


uint8 StatusRegister1;
uint8 InterruptCnt1;
uint8 StatusRegister2;
uint8 InterruptCnt2;

/*******************************************************************************
* Define Interrupt service routine and allocate an vector to the Interrupt
********************************************************************************/
CY_ISR(InterruptHandler1)
{
    StatusRegister1 = Timer_1_ReadStatusRegister();
    /* Increment the Counter to indicate the keep track of the number of 
     * interrupts received */
    InterruptCnt1++;    
}

CY_ISR(InterruptHandler2)
{
    StatusRegister2 = Timer_2_ReadStatusRegister();
    /* Increment the Counter to indicate the keep track of the number of 
     * interrupts received */
    InterruptCnt2++;    
}

void InitializeHardware(void)
{
	
    CyGlobalIntEnable;
	
	Comp_1_ZeroCal();
	Comp_2_ZeroCal();
	Comp_3_ZeroCal();
	Comp_4_ZeroCal();
	
	Comp_1_Start();
	Comp_2_Start();
	Comp_3_Start();
	Comp_4_Start();
	
	TimerISR_1_StartEx(InterruptHandler1);
	
	TimerISR_2_StartEx(InterruptHandler2);

    
	/* The clocks are defined to start automatically, no need to start them again * /
    clock_1_Enable();
    clock_2_Enable();
	clock_3_Enable();
    clock_4_Enable();
/* */	
    Timer_1_Start();
    Timer_2_Start();

    /* Display TMR-16 on LCD */
    LCD_Start(); // The pins for the LCD must be set to Port2[0..6] 
}

void main()
{

	uint32 period1;
	uint32 counter1;
	uint32 intcnt1;
	float time1;
	char timeStr1[10];
	
	uint32 period2;
	uint32 counter2;
	uint32 intcnt2;
	float time2;
	char timeStr2[10];	
// This could be killing your application in PSoC1. You are using permanently 52 Bytes on the stack for local vars	

	InitializeHardware();
	

    while(forever)
    {
        /* To display Interrupt count on LCD */
		intcnt1 = InterruptCnt1;
		period1 = Timer_1_ReadPeriod();
		counter1 = Timer_1_ReadCounter();
		time1 = intcnt1 + (period1 - counter1) / (float)period1;
		time1 = time1 * (((float)period1+1) / 10); //ms
		sprintf(timeStr1,"%5.2f ms" , time1); 
		LCD_Position(0,0);
        LCD_PrintString(timeStr1);
		
		intcnt2 = InterruptCnt2;
		period2 = Timer_2_ReadPeriod();
		counter2 = Timer_2_ReadCounter();
		time2 = intcnt2 + (period2 - counter2) / (float)period2;
		time2 = time2 * (((float)period2 + 1) / 10); //ms
		sprintf(timeStr2,"%5.2f ms" , time2); 
		LCD_Position(1,0);
        LCD_PrintString(timeStr2);
    }
}

/* [] END OF FILE */
